<?php

namespace Rapsys\AirBundle\Pdf;

class DisputePdf extends \Fpdf\Fpdf {
	//Generate gathering dispute
	public static function genGathering($court, $notice, $agent, $service, $abstract, $civility, $forename, $surname) {
		//Create new pdf
		$p = new DisputePdf('P', 'mm', 'A4');

		//Set author
		$p->SetAuthor('Réaction 19', true);

		//Set creator
		$p->SetCreator(basename(__FILE__), true);

		//Set subject
		$p->SetSubject('Contestation de contravention pour rassemblement interdit sur la voie publique', true);

		//Set title
		$p->SetTitle('Modèle de contestation', true);

		//Disable auto page break
		$p->SetAutoPageBreak(true, 10);

		//Add page
		$p->AddPage('P', 'A4', 0);

		//Add text
		$p->Multi('À '.ucfirst(trim($court)).' le '.date('d/m/Y'), 0, '', 10, 4, 'R');

		//Save x
		$x = $p->GetX();

		//Set margins
		$p->SetXY(105, 60);

		//Add formal
		$p->Multi('L\'OFFICIER DU MINISTÈRE PUBLIC
PRÈS LE TRIBUNAL DE POLICE DE
'.strtoupper(trim($court)), 0, '', 12);

		//Jump line
		$p->Ln(16);

		//Add notice number
		$p->Multi('Numéro avis : '.trim($notice), 6, 'B', 10, 2);

		//Add object
		$p->Multi('Objet : CONTESTATION DE CONTRAVENTION', 6, 'B', 10, 6);

		//Add text
		$p->Multi('Madame, Monsieur l\'Officier du Ministère Public,

Par la présente, j\'entends former opposition à l\'encontre de l\'avis de contravention référencé ci-avant dressé à mon encontre.

A cette fin, je vous prie de bien vouloir trouver sous ce pli le formulaire de requête en exonération dûment rempli, ainsi que l\'original de l\'avis de contravention.

Après un rappel des faits et de la procédure qui ont conduit à dresser cet avis de contravention (I), il sera démontré que ledit avis est entaché d\'irrégularité manifeste (II).');

		//Add title
		$p->Title1('I/ RAPPEL DES FAITS OBJET DE LA PRESENTE CONTRAVENTION');

		//Add text
		$p->Body('L\'avis de contravention contesté m\'a été adressé en raison d\'une prétendue participation à un rassemblement interdit sur la voie publique, dans les termes suivants :');

		//Add text
		$p->Quoted('« Rassemblement interdit sur la voie publique dans une circonscription territoriale en état d\'urgence sanitaire et devant faire face à l\'épidémie de Covid-19 ».', 'BI');

		//Add text
		$p->Quoted('étant précisé qu\'il est visé à l\'avis de contravention les articles « L.3131-15 §1 6°, L.3131-13, L 3131-16 al.2, L 3131-17 §1 du Code de la santé publique, Art 3, art 3-1 al. 2, art. 1 du décret du 2020-1310 du 29-10-2020 » et en répression l\'article L.3136-1 al.3 du Code de la santé publique.');

		//Add text
		$p->Body('Cette infraction a été constatée et validée par un agent verbalisateur'.(!empty($agent)?' numéro '.trim($agent):'').(!empty($service)?' doté du code service '.trim($service):'').', sans plus de précision quant à sa qualité exacte.');

		//With abstract
		if (!empty($abstract)) {
			//Add text
			$p->Body(trim($abstract));
		}

		//Add title
		$p->Title1('II/ UN AVIS DE CONTRAVENTION ENTACHÉ D\'IRRÉGULARITÉ MANIFESTE');

		//Add title
		$p->Title2('II.1 - L\'article 3136-1 du code la santé publique visé à l\'avis de contravention ne réprime pas l\'infraction de rassemblement interdit');

		//Add ittle
		$p->Title3('(i) En droit - le principe de l\'application stricte de la loi pénale');

		//Add text
		$p->Body('L\'article 111-4 du code pénal dispose :');

		//Add text
		$p->Quoted('« La loi pénale est d\'interprétation stricte. »');

		//Add text
		$p->Body('La Cour Européenne des Droits de l\'Homme a reconnu que le principe de l\'interprétation stricte de la loi pénale constituait un corollaire du principe de légalité (cf. CEDH, 25 mai 1993, Kokkinakis c. Grèce).

Il est ainsi admis que le principe de l\'interprétation stricte de la loi pénale a une valeur normative équivalente aux principes affirmés à l\'article 7 § 1 de la Convention et qu\'il contribue, à l\'instar de ces derniers, à protéger les individus contre toute forme de répression arbitraire.

La jurisprudence constante de la Chambre criminelle de la Cour de Cassation interdit au demeurant toute interprétation par « extension, analogie ou induction » (Cass. Crim 9 août 1913- Cass. Crim 1er juin 1977 n°76.91-999).

Seule une loi pénale obscure peut faire l\'objet d\'une interprétation.

En conséquence de l\'application de ce principe, dès lors qu\'une loi pénale est dépourvue de toute ambiguïté, celle-ci doit être interprétée strictement.');

		//Add title
		$p->Title3('(ii) En fait');

		//Add text
		$p->Body('L\'avis de contravention vise l\'article 3136-1 alinéa 3 du code de la santé publique, lequel dispose :');

		//Add text
		$p->Quoted('« La violation des autres interdictions ou obligations édictées en application des articles L. 3131-1 et L. 3131-15 à L. 3131-17 est punie de l\'amende prévue pour les contraventions de la quatrième classe. Cette contravention peut faire l\'objet de la procédure de l\'amende forfaitaire prévue à l\'article 529 du code de procédure pénale. Si cette violation est constatée à nouveau dans un délai de quinze jours, l\'amende est celle prévue pour les contraventions de la cinquième classe. ».');

		//Add text
		$p->Body('Force est de constater que ce texte de répression renvoie à des textes de prévention dont il édicte prétendument la sanction.

Ce texte répressif vise les articles L. 3131-1 et L. 3131-15 à L. 3131-17 du code de la santé publique.

Or, ces quatre articles ne définissent pas l\'infraction de rassemblement interdit :');

		//Add text
		$p->Quoted('- Les violations des interdictions ou obligations édictées par l\'article 3131-1 du CSP à savoir les mesures prises sur arrêté du 1er ministre et/ou des préfets pour des mesures individuelles ou collectives ne mentionnent pas une quelconque interdiction de rassemblement;
- Les violations des interdictions ou obligations édictées par l\'article 3131-15 du CSP c\'est-à-dire des mesures prises par le 1er ministre « dans les circonscriptions territoriales où l\'état d\'urgence sanitaire est déclaré ». Cet article n\'incrimine pas les rassemblements sur la voie publique. 
- Les violations des interdictions ou obligations édictées par l\'article 3131-16 CSP c\'est-à-dire des mesures prises par le ministre de la santé « dans les circonscriptions territoriales où l\'état d\'urgence sanitaire est déclaré ». Cet article ne vise pas les rassemblements interdits,
- Les violations des interdictions ou obligations édictées par l\'article 3131-17 CSP c\'est-à-dire des mesures prises par le représentant de l\'Etat territorialement compétent, dûment habilité par le 1 er ministre ou le ministre de la santé ne mentionnent pas une quelconque interdiction de rassemblement.');

		//Add text
		$p->Body('En d\'autres termes, l\'article L. 3136-1 alinéa 3 du code de la santé publique renvoie à des textes de prévention qui ne définissent pas l\'infraction de rassemblement interdit sur la voie publique dans une circonscription territoriale en état d\'urgence sanitaire ou devant faire face à l\'épidémie de COVID-19.');

		//Add text
		$p->Body('Par conséquent, l\'article L. 3136-1 alinéa 3 du code de la santé publique ne réprime pas les rassemblements interdits sur la voie publique.
Dès lors, l\'avis de contravention ne mentionne pas le texte de répression de l\'infraction qui m\'est reprochée.', 'BU');

		//Add text
		$p->Body('L\'absence de cette mention entache l\'avis de contravention d\'irrégularité manifeste.', 'B');

		//Add title
		$p->Title2('II.2 En tout état de cause, le non-respect du principe de légalité');

		//Add title
		$p->Title3('(i) En droit');

		//Add text
		$p->Body('Le droit pénal français est fondé sur le principe fondamental de la légalité des délits et des peines selon lequel quiconque ne peut être condamné en l\'absence d\'un texte clair et précis.

Ce principe est au demeurant consacré par l\'article 8 de la Déclaration des droits de l\'Homme et du Citoyen de 1789 et a donc une valeur constitutionnelle.

Plus encore, l\'article 111-3 du code pénal dispose : ');

		//Add text
		$p->Quoted('« Nul ne peut être puni pour un crime ou pour un délit dont les éléments ne sont pas définis par la loi, ou pour une contravention dont les éléments ne sont pas définis par le règlement.

Nul ne peut être puni d\'une peine qui n\'est pas prévue par la loi, si l\'infraction est un crime ou un délit, ou par le règlement, si l\'infraction est une contravention. »');

		//Add text
		$p->Body('Il en découle que chaque justiciable doit être en mesure de connaître non seulement les textes prévoyant l\'incrimination d\'un comportement déterminé mais également les textes fondant les peines applicables à l\'infraction visée. 

En matière de contraventions, l\'article A37-4 du Code de procédure pénale prévoit :');

		//Add text
		$p->Quoted('« Les caractéristiques de l\'avis de contravention mentionné à l\'article A.37-1 sont les suivantes:
I. Sur la partie gauche sont portées les mentions relatives au service verbalisateur, à la nature, au lieu et à la date de la contravention ainsi que les références des textes réprimant ladite contravention et, le cas échéant, sont précisés les éléments d\'identification du véhicule et l\'obligation de procéder à l\'échange du permis de conduire.

Ainsi, le Code de procédure pénale exige, comme condition de recevabilité et conformément au principe de légalité, que les textes répressifs soient mentionnés à l\'acte de contravention.');

		//Add title
		$p->Title3('(ii) En fait');

		//Add text
		$p->Body('En prévention, l\'avis de contravention précité mentionne un certain nombre d\'articles :

- L\'article L.3131-15 §I 6° du Code de la santé publique :');

		//Add text
		$p->Quoted('« I. Dans les circonscriptions territoriales où l\'état d\'urgence sanitaire est déclaré, le Premier ministre peut, par décret réglementaire pris sur le rapport du ministre chargé de la santé, aux seules fins de garantir la santé publique :

(...)

6° Limiter ou interdire les rassemblements sur la voie publique ainsi que les réunions de toute nature ;»');

		//Add text
		$p->Body('Cet alinéa mentionne la faculté par le Premier Ministre de limiter ou interdire des rassemblements sur la voie publique ainsi que les réunions de toute nature, par voie de décret spécifique.
Ce texte ne prévoit donc pas l\'infraction qui m\'est reprochée.

-L\'article L.3131-13 du même code, est également mentionné sans référence à un alinéa en particulier :');

		//Add text
		$p->Quoted('« L\'état d\'urgence sanitaire est déclaré par décret en conseil des ministres pris sur le rapport du ministre chargé de la santé. Ce décret motivé détermine la ou les circonscriptions territoriales à l\'intérieur desquelles il entre en vigueur et reçoit application. Les données scientifiques disponibles sur la situation sanitaire qui ont motivé la décision sont rendues publiques.

		L\'Assemblée nationale et le Sénat sont informés sans délai des mesures prises par le Gouvernement au titre de l\'état d\'urgence sanitaire. L\'Assemblée nationale et le Sénat peuvent requérir toute information complémentaire dans le cadre du contrôle et de l\'évaluation de ces mesures.

		La prorogation de l\'état d\'urgence sanitaire au-delà d\'un mois ne peut être autorisée que par la loi, après avis du comité de scientifiques prévu à l\'article L. 3131-19. »');

		//Add text
		$p->Body('Cette disposition est donc relative à l\'état d\'urgence sanitaire.

- L\'article 3131-17 §1 du code de la santé publique, également cité à la prévention, dispose quant à lui :');

		//Add text
		$p->Quoted('« I. - Lorsque le Premier ministre ou le ministre chargé de la santé prennent des mesures mentionnées aux articles L. 3131-15 et L. 3131-16, ils peuvent habiliter le représentant de l\'Etat territorialement compétent à prendre toutes les mesures générales ou individuelles d\'application de ces dispositions.

Lorsque les mesures prévues aux 1°, 2° et 5° à 9° du I de l\'article L. 3131-15 et à l\'article L. 3131-16 doivent s\'appliquer dans un champ géographique qui n\'excède pas le territoire d\'un département, les autorités mentionnées aux mêmes articles L. 3131-15 et L. 3131-16 peuvent habiliter le représentant de l\'Etat dans le département à les décider lui-même. Les décisions sont prises par ce dernier après avis du directeur général de l\'agence régionale de santé. ».');

		//Add text
		$p->Body('L\'article 3131-16 al. 2 dispose que :');

		//Add text
		$p->Quoted('« Dans les mêmes conditions, le ministre chargé de la santé peut prescrire toute mesure individuelle nécessaire à l\'application des mesures prescrites par le Premier ministre en application des 1° à 9° du I de l\'article L. 3131-15. ».');

		//Add text
		$p->Body('- Outre ces dispositions, sont également visés les articles 1 et 3 du décret 2020-1310 du 29 octobre 2020 à savoir :');

		//Add text
		$p->Quoted('«I. - Afin de ralentir la propagation du virus, les mesures d\'hygiène définies en annexe 1 au présent décret et de distanciation sociale, incluant la distanciation physique d\'au moins un mètre entre deux personnes, dites barrières, définies au niveau national, doivent être observées en tout lieu et en toute circonstance.

II. - Les rassemblements, réunions, activités, accueils et déplacements ainsi que l\'usage des moyens de transports qui ne sont pas interdits en vertu du présent décret sont organisés en veillant au strict respect de ces mesures. Dans les cas où le port du masque n\'est pas prescrit par le présent décret, le préfet de département est habilité à le rendre obligatoire, sauf dans les locaux d\'habitation, lorsque les circonstances locales l\'exigent.».');

		//Add text
		$p->Quoted('«I. - Tout rassemblement, réunion ou activité sur la voie publique ou dans un lieu ouvert au public, qui n\'est pas interdit par le présent décret, est organisé dans des conditions de nature à permettre le respect des dispositions de l\'article 1er.
II. - Les organisateurs des manifestations sur la voie publique mentionnées à l\'article L. 211-1 du code de la sécurité intérieure adressent au préfet de département sur le territoire duquel la manifestation doit avoir lieu, sans préjudice des autres formalités applicables, une déclaration contenant les mentions prévues à l\'article L. 211-2 du même code, en y précisant, en outre, les mesures qu\'ils mettent en œuvre afin de garantir le respect des dispositions de l\'article 1er du présent décret.
Sans préjudice des dispositions de l\'article L. 211-4 du code de la sécurité intérieure, le préfet peut en prononcer l\'interdiction si ces mesures ne sont pas de nature à permettre le respect des dispositions de l\'article 1er.
III. - Les rassemblements, réunions ou activités sur la voie publique ou dans un lieu ouvert au public autres que ceux mentionnés au II mettant en présence de manière simultanée plus de six personnes sont interdits.
Ne sont pas soumis à cette interdiction :
1° Les rassemblements, réunions ou activités à caractère professionnel ;
2° Les services de transport de voyageurs ;
3° Les établissements recevant du public dans lesquels l\'accueil du public n\'est pas interdit en application du présent décret ;
4° Les cérémonies funéraires organisées hors des établissements mentionnés au 3°, dans la limite de 30 personnes ;
5° Les cérémonies publiques mentionnées par le décret du 13 septembre 1989 susvisé.
La dérogation mentionnée au 3° n\'est pas applicable pour la célébration de mariages.
IV. - Le préfet de département est habilité à interdire ou à restreindre, par des mesures réglementaires ou individuelles, tout rassemblement, réunion ou activité mettant en présence de manière simultanée plus de six personnes sur la voie publique ou dans des lieux ouverts au public relevant du III, lorsque les circonstances locales l\'exigent. Toutefois, dans les collectivités de l\'article 74 de la Constitution et en Nouvelle-Calédonie, sous réserve que le présent décret leur soit applicable en vertu des dispositions de l\'article 55, le représentant de l\'Etat est habilité à prendre des mesures d\'interdiction proportionnées à l\'importance du risque de contamination en fonction des circonstances locales, après avis de l\'autorité compétente en matière sanitaire.»');

		//Add text
		$p->Body('- En répression, il est renvoyé à l\'article L.3136-1 du Code de la santé publique en son 3ème alinéa, dont le contenue est le suivant :');

		//Add text
		$p->Quoted('« La violation des autres interdictions ou obligations édictées en application des articles L. 3131-1 et L. 3131-15 à L. 3131-17 est punie de l\'amende prévue pour les contraventions de la quatrième classe. Cette contravention peut faire l\'objet de la procédure de l\'amende forfaitaire prévue à l\'article 529 du code de procédure pénale. Si cette violation est constatée à nouveau dans un délai de quinze jours, l\'amende est celle prévue pour les contraventions de la cinquième classe. ».');

		//Add text
		$p->Body('Cet alinéa 3 mentionne successivement l\'amende prévue pour les contraventions de la quatrième classe, ainsi que celle prévue pour la cinquième classe en cas de récidive dans un délai de 15 jours.');

		//Add text
		$p->Body('En aucun cas, il n\'est précisé la catégorie de contravention applicable à ma situation spécifique.

Plus encore, outre la confusion générée par la référence à deux classes de contravention, en aucun cas l\'article précité, ou l\'article 529 du Code de procédure pénale ne fixent le montant de l\'amende forfaitaire à laquelle je suis condamné.', 'BU');

		//Add text
		$p->Body('En effet, cette information ressort de l\'article R. 49 du Code de procédure pénale, qui dispose :');

		//Add text
		$p->Quoted('« Le montant de l\'amende forfaitaire prévue par l\'article 529 est fixé ainsi qu\'il suit : [...]

5° 135 euros pour les contraventions de la 4e classe 

6° 200 euros pour les contraventions de la 5e classe ».', 'BI');

		//Add text
		$p->Body('Or, cet article n\'est nullement mentionné à l\'avis de contravention reçu !

Par conséquent, l\'avis de contravention dressé à mon encontre est entaché d\'irrégularité.', 'B');

		//Add text
		$p->Body('A tout point de vue, l\'avis de contravention reçu souffre de plusieurs manquements graves de base légale à savoir :', 'B');

		//Add text
		$p->Quoted('- L\'avis de contravention est dépourvu de base légale puisque l\'infraction prétendument commise n\'est pas visée par un texte de répression ;

- A considérer qu\'il soit besoin d\'examiner le contenu de l\'avis de contravention, il devra être considéré qu\'au regard du principe de légalité, lequel a pour corollaire le principe de légalité des peines, les textes de prévention ne sont pas correctement visés.', 'BU');

		//Add text
		$p->Body('Or, en application des principes fondamentaux et constitutionnels, un fait ne peut être réprimé pénalement qu\'en vertu d\'une disposition pénale suffisamment précise et claire, et ce afin notamment d\'exclure tout arbitraire dans le prononcé des peines.');

		//Add text
		$p->Body('Par conséquent, cette condamnation pénale constitue une violation des principes essentiels rappelés.', 'BU');

		//Add text
		$p->Body('Pour l\'ensemble de ces raisons, je vous remercie, Madame ou Monsieur l\'Officier du Ministère Public, de faire droit à cette requête en me confirmant que vous renoncez à toute poursuite du chef de la contravention contestée et, le cas échéant, vous invite à me convoquer à une prochaine audience.

Vous remerciant de l\'accueil et l\'attention que vous réserverez à la présente,

Je vous prie d\'agréer, Madame, Monsieur l\'Officier du Ministère Public, l\'expression de mes sentiments distingués.');

		//Add text
		$p->Body('Signé, '.$civility.' '.$forename.' '.$surname);

		//Close pdf
		$p->Close();

		//Return pdf
		return $p->Output('S');

	}

	//Generate traffic dispute
	public static function genTraffic($court, $notice, $agent, $service, $abstract, $civility, $forename, $surname) {
		//Create new pdf
		$p = new DisputePdf('P', 'mm', 'A4');

		//Set author
		$p->SetAuthor('Réaction 19', true);

		//Set creator
		$p->SetCreator(basename(__FILE__), true);

		//Set subject
		$p->SetSubject('Contestation de contravention pour circulation à une heure interdite', true);

		//Set title
		$p->SetTitle('Modèle de contestation', true);

		//Disable auto page break
		$p->SetAutoPageBreak(true, 10);

		//Add page
		$p->AddPage('P', 'A4', 0);

		//Add text
		$p->Multi('À '.ucfirst(trim($court)).' le '.date('d/m/Y'), 0, '', 10, 4, 'R');

		//Save x
		$x = $p->GetX();

		//Set margins
		$p->SetXY(105, 60);

		//Add formal
		$p->Multi('L\'OFFICIER DU MINISTÈRE PUBLIC
PRÈS LE TRIBUNAL DE POLICE DE
'.strtoupper(trim($court)), 0, '', 12);

		//Jump line
		$p->Ln(16);

		//Add notice number
		$p->Multi('Numéro avis : '.trim($notice), 6, 'B', 10, 2);

		//Add object
		$p->Multi('Objet : CONTESTATION DE CONTRAVENTION', 6, 'B', 10, 6);

		//Add text
		$p->Multi('Madame, Monsieur l\'Officier du Ministère Public,

Par la présente, j\'entends former opposition à l\'encontre de l\'avis de contravention référencé ci-avant dressé à mon encontre.

A cette fin, je vous prie de bien vouloir trouver sous ce pli le formulaire de requête en exonération dûment rempli, ainsi que l\'original de l\'avis de contravention.

Après un rappel des faits et de la procédure qui ont conduit à dresser cet avis de contravention (I), il sera démontré que ledit avis est entaché d\'irrégularité manifeste (II).');

		//Add title
		$p->Title1('I/ RAPPEL DES FAITS OBJET DE LA PRESENTE CONTRAVENTION');

		//Add text
		$p->Body('L\'avis de contravention contesté m\'a été adressé en raison d\'une prétendue violation d\'une interdiction de déplacement à une heure interdite, dans les termes suivants :');

		//Add text
		$p->Quoted('« Circulation à une heure interdite dans une circonscription territoriale en état d\'urgence sanitaire et devant faire face à l\'épidémie de COVID-19 ».', 'BI');

		//Add text
		$p->Quoted('étant précisé qu\'il est visé à l\'avis de contravention les articles L.3131-15 §I 1°, L.3131-13 du Code de la santé publique, 3131-16 alinéa 2, 3131-17 §1, les articles 4 et 4-1 du décret 2020-1310 du 29-10-2020, et en répression l\'article L.3136-1 al. 3 du Code de la santé publique.');

		//Add text
		$p->Body('Cette infraction a été constatée et validée par un agent verbalisateur'.(!empty($agent)?' numéro '.trim($agent):'').(!empty($service)?' doté du code service '.trim($service):'').', sans plus de précision quant à sa qualité exacte.');

		//With abstract
		if (!empty($abstract)) {
			//Add text
			$p->Body(trim($abstract));
		}

		//Add title
		$p->Title1('II/ UN AVIS DE CONTRAVENTION ENTACHÉ D\'IRRÉGULARITÉ MANIFESTE');

		//Add title
		$p->Title2('II.1 - Une infraction non réprimée par l\'article visé, à savoir l\'article 3136-1 al. 3 du code de la santé publique');

		//Add title
		$p->Title3('(i) En droit - le principe de l\'application stricte de la loi pénale');

		//Add text
		$p->Body('L\'article 111-4 du code pénal dispose :');

		//Add text
		$p->Quoted('« La loi pénale est d\'interprétation stricte. »', 'I');

		//Add text
		$p->Body('La Cour Européenne des Droits de l\'Homme a reconnu que le principe de l\'interprétation stricte de la loi pénale constituait un corollaire du principe de légalité (cf. CEDH, 25 mai 1993, Kokkinakis c. Grèce).

Il est ainsi admis que le principe de l\'interprétation stricte de la loi pénale a une valeur normative équivalente aux principes affirmés à l\'article 7 § 1 de la Convention et qu\'il contribue, à l\'instar de ces derniers, à protéger les individus contre toute forme de répression arbitraire.');

		//Add text
		$p->Body('La jurisprudence constante de la Chambre criminelle de la Cour de Cassation interdit au demeurant toute interprétation par « extension, analogie ou induction » (Cass. Crim 9 août 1913- Cass. Crim 1er juin 1977 n°76.91-999).

Seule une loi pénale obscure peut faire l\'objet d\'une interprétation.

En conséquence de l\'application de ce principe, dès lors qu\'une loi pénale est dépourvue de toute ambiguïté, celle-ci doit être interprétée strictement.');

		//Add title
		$p->Title3('(ii) En fait');

		//Add text
		$p->Body('Sur la répression, l\'avis de contravention vise l\'article 3136-1 alinéa 3 du code de la santé publique, lequel dispose :');

		//Add text
		$p->Quoted('« La violation des autres interdictions ou obligations édictées en application des articles L. 3131-1 et L. 3131-15 à L. 3131-17 est punie de l\'amende prévue pour les contraventions de la quatrième classe. Cette contravention peut faire l\'objet de la procédure de l\'amende forfaitaire prévue à l\'article 529 du code de procédure pénale. Si cette violation est constatée à nouveau dans un délai de quinze jours, l\'amende est celle prévue pour les contraventions de la cinquième classe. ».');

		//Add text
		$p->Body('Force est de constater que ce texte de répression renvoie à des textes de prévention dont il édicte la sanction.', 'B');

		//Add text
		$p->Body('Ce texte répressif vise les articles L. 3131-1 et L. 3131-15 à L. 3131-17 du code de la santé publique.

Or, ces quatre articles ne définissent pas l\'infraction de circulation à une heure interdite :');

		//Add text
		$p->Quoted('- Les violations des interdictions ou obligations édictées par l\'article 3131-1 du CSP à savoir les mesures prises sur arrêté du 1er ministre et/ou des préfets pour des mesures individuelles ou collectives ne mentionnent pas une quelconque circulation à une heure interdite;

- Les violations des interdictions ou obligations édictées par l\'article 3131-15 du CSP c\'est-à-dire des mesures prises par le 1er ministre « dans les circonscriptions où l\'état d\'urgence sanitaire est déclaré ». Cet article n\'incrimine pas la circulation à une heure interdite;

- Les violations des interdictions ou obligations édictées par l\'article 3131-16 CSP c\'est-à-dire des mesures prises par le ministre de la santé « dans les circonscriptions où l\'état d\'urgence sanitaire est déclaré ». Cet article ne vise la circulation à une heure interdite;

- Les violations des interdictions ou obligations édictées par l\'article 3131-17 CSP c\'est-à-dire des mesures prises par le représentant de l\'État territorialement compétent, dûment habilité par le 1er ministre ou le ministre de la santé ne mentionnent pas une quelconque interdiction de circulation à une heure interdite.', '');

		//Add text
		$p->Body('En d\'autres termes, l\'article L. 3136-1 alinéa 3 du code de la santé publique renvoie à des textes de prévention qui ne définissent pas l\'infraction de circulation à une heure interdite.');

		//Add text
		$p->Body('Par conséquent, l\'article L. 3136-1 alinéa 3 du code de la santé publique ne réprime pas la circulation à une heure interdite.

Dès lors, force est de constater que l\'avis de contravention ne mentionne pas le texte de répression de l\'infraction qui m\'est reprochée.', 'BU');

		//Add text
		$p->Body('L\'absence de cette mention entache l\'avis de contravention d\'irrégularité manifeste.', 'B');

		//Add title
		$p->Title2('II.2 Sur le non-respect du principe de légalité');

		//Add title
		$p->Title3('(i) En droit');

		//Add text
		$p->Body('Le droit pénal français est fondé sur le principe fondamental de la légalité des délits et des peines selon lequel quiconque ne peut être condamné en l\'absence d\'un texte clair et précis.

Ce principe est au demeurant consacré par l\'article 8 de la Déclaration des droits de l\'Homme et du Citoyen de 1789 et a donc une valeur constitutionnelle.

Plus encore, l\'article 111-3 du code pénal dispose :');

		//Add text
		$p->Quoted('« Nul ne peut être puni pour un crime ou pour un délit dont les éléments ne sont pas définis par la loi, ou pour une contravention dont les éléments ne sont pas définis par le règlement.

Nul ne peut être puni d\'une peine qui n\'est pas prévue par la loi, si l\'infraction est un crime ou un délit, ou par le règlement, si l\'infraction est une contravention. »');

		//Add text
		$p->Body('Il en découle que chaque justiciable doit être en mesure de connaître non seulement les textes prévoyant l\'incrimination d\'un comportement déterminé mais également les textes fondant les peines applicables à l\'infraction visée.', 'U');

		//Add text
		$p->Body('En matière de contraventions, l\'article A37-4 du Code de procédure pénale prévoit :');

		//Add text
		$p->Quoted('« Les caractéristiques de l\'avis de contravention mentionné à l\'article A.37-1 sont les suivantes :
I. Sur la partie gauche sont portées les mentions relatives au service verbalisateur, à la nature, au lieu et à la date de la contravention ainsi que les références des textes réprimant ladite contravention et, le cas échéant, sont précisés les éléments d\'identification du véhicule et l\'obligation de procéder à l\'échange du permis de conduire. »');

		//Add text
		$p->Body('Ainsi, le Code de procédure pénale exige, comme condition de recevabilité et conformément au principe de légalité, que les textes répressifs soient mentionnés à l\'acte de contravention.', 'B');

		//Add title
		$p->Title3('(ii) En fait');

		//Add text
		$p->Body('En prévention, l\'avis de contravention précité mentionne en prévention l\'article L.3131-15 §I 1° du Code de la santé publique :');

		//Add text
		$p->Quoted('« I.- Dans les circonscriptions territoriales où l\'état d\'urgence sanitaire est déclaré, le Premier ministre peut, par décret réglementaire pris sur le rapport du ministre chargé de la santé, aux seules fins de garantir la santé publique :

1° Réglementer ou interdire la circulation des personnes et des véhicules et réglementer l\'accès aux moyens de transport et les conditions de leur usage ;
[...] »');

		//Add text
		$p->Body('Ainsi que l\'article L.3131-13 du Code de la santé publique, sans référence à un alinéa en particulier :');

		//Add text
		$p->Quoted('« L\'état d\'urgence sanitaire est déclaré par décret en conseil des ministres pris sur le rapport du ministre chargé de la santé. Ce décret motivé détermine la ou les circonscriptions territoriales à l\'intérieur desquelles il entre en vigueur et reçoit application. Les données scientifiques disponibles sur la situation sanitaire qui ont motivé la décision sont rendues publiques.

L\'Assemblée nationale et le Sénat sont informés sans délai des mesures prises par le Gouvernement au titre de l\'état d\'urgence sanitaire. L\'Assemblée nationale et le Sénat peuvent requérir toute information complémentaire dans le cadre du contrôle et de l\'évaluation de ces mesures.

La prorogation de l\'état d\'urgence sanitaire au-delà d\'un mois ne peut être autorisée que par la loi, après avis du comité de scientifiques prévu à l\'article L. 3131-19. »');

		//Add text
		$p->Body('Sont également visées, les dispositions de l\'article 3131-16 alinéa 2, desquelles il ressort :');

		//Add text
		$p->Quoted('« Dans les mêmes conditions, le ministre chargé de la santé peut prescrire toute mesure individuelle nécessaire à l\'application des mesures prescrites par le Premier ministre en application des 1° à 9° du I de l\'article L. 3131-15. ».');

		//Add text
		$p->Body('Les dispositions de l\'article 3131-17 §1 également visées par l\'avis de contravention prévoient quant à elles que :');

		//Add text
		$p->Quoted('« I. - Lorsque le Premier ministre ou le ministre chargé de la santé prennent des mesures mentionnées aux articles L. 3131-15 et L. 3131-16, ils peuvent habiliter le représentant de l\'Etat territorialement compétent à prendre toutes les mesures générales ou individuelles d\'application de ces dispositions.

Lorsque les mesures prévues aux 1°, 2° et 5° à 9° du I de l\'article L. 3131-15 et à l\'article L. 3131-16 doivent s\'appliquer dans un champ géographique qui n\'excède pas le territoire d\'un département, les autorités mentionnées aux mêmes articles L. 3131-15 et L. 3131-16 peuvent habiliter le représentant de l\'Etat dans le département à les décider lui-même. Les décisions sont prises par ce dernier après avis du directeur général de l\'agence régionale de santé. ».');

		//Add text
		$p->Body('Outre ces dispositions, est également visé l\'article 4 du décret 2020-1310 du 29 octobre 2020, en vigueur à la date des faits :');

		//Add text
		//XXX: https://www.legifrance.gouv.fr/loda/id/LEGIARTI000043330006/2021-04-04/
		$p->Quoted('I.-Tout déplacement de personne hors de son lieu de résidence est interdit entre 19 heures et 6 heures du matin à l\'exception des déplacements pour les motifs suivants, en évitant tout regroupement de personnes :

1° Déplacements à destination ou en provenance :

a) Du lieu d\'exercice ou de recherche d\'une activité professionnelle et déplacements professionnels ne pouvant être différés ;

b) Des établissements ou services d\'accueil de mineurs, d\'enseignement ou de formation pour adultes mentionnés aux articles 32 à 35 du présent décret ;

c) Du lieu d\'organisation d\'un examen ou d\'un concours ;

2° Déplacements pour des consultations, examens, actes de prévention et soins ne pouvant être assurés à distance ou pour l\'achat de produits de santé ;

3° Déplacements pour motif familial impérieux, pour l\'assistance aux personnes vulnérables ou précaires ou pour la garde d\'enfants ;

4° Déplacements des personnes en situation de handicap et, le cas échéant, de leur accompagnant ;

5° Déplacements pour répondre à une convocation judiciaire ou administrative ou pour se rendre chez un professionnel du droit pour un acte ou une démarche qui ne peuvent être réalisés à distance ;

6° Déplacements pour participer à des missions d\'intérêt général sur demande de l\'autorité administrative ;

7° Déplacements liés à des transferts ou transits vers ou depuis des gares ou aéroports dans le cadre de déplacements de longue distance relevant de l\'un des motifs mentionnés au présent article ;

8° Déplacements brefs, dans un rayon maximal d\'un kilomètre autour du domicile pour les besoins des animaux de compagnie.

II.-Tout déplacement de personne hors de son lieu de résidence est interdit entre 6 heures et 19 heures à l\'exception des déplacements pour les motifs mentionnés au I et les motifs suivants, en évitant tout regroupement de personnes :

1° Déplacements pour effectuer des achats de fournitures nécessaires à l\'activité professionnelle ou pour des livraisons à domicile ;

2° Déplacements pour effectuer des achats de première nécessité, des retraits de commandes ou pour les besoins de prestations de services qui ne sont pas interdites en application des chapitres 1er et 3 du titre IV du présent décret ;

3° Déplacements liés à un déménagement résultant d\'un changement de domicile et déplacements indispensables à l\'acquisition ou à la location d\'une résidence principale, insusceptibles d\'être différés ;

4° Déplacements, dans un rayon maximal de dix kilomètres autour du domicile, liés soit à la promenade, soit à l\'activité physique individuelle des personnes, à l\'exclusion de toute pratique sportive collective ;

5° Déplacements pour se rendre dans un service public, pour un acte ou une démarche qui ne peuvent être réalisés à distance ;

6° Déplacements à destination ou en provenance d\'un lieu de culte ;

7° Participation à des rassemblements, réunions ou activités sur la voie publique ou dans un lieu ouvert au public qui ne sont pas interdits en application de l\'article 3.

II bis.-Les déplacements mentionnés aux 2°, 5°, 6° du II, ainsi que ceux mentionnés à son 7° lorsqu\'ils ne relèvent pas du II de l\'article 3, s\'effectuent dans les limites du département de résidence de la personne ou, en dehors de celui-ci, dans un périmètre de 30 kilomètres autour de son domicile.

III.-Les personnes souhaitant bénéficier de l\'une des exceptions mentionnées aux I et II se munissent, lors de leurs déplacements hors de leur domicile, d\'un document leur permettant de justifier que le déplacement considéré entre dans le champ de l\'une de ces exceptions.

Les interdictions de déplacement mentionnées aux I et II ne peuvent faire obstacle à l\'exercice d\'une activité professionnelle sur la voie publique dont il est justifié dans les conditions prévues à l\'alinéa précédent.

IV.-Le représentant de l\'Etat dans le département est habilité à adopter des mesures plus restrictives en matière de trajets et déplacements des personnes lorsque les circonstances locales l\'exigent. Toutefois, dans les collectivités mentionnées à l\'article 72-3 de la Constitution, sous réserve que le présent décret leur soit applicable en vertu des dispositions de l\'article 55, le représentant de l\'Etat est habilité à prendre des mesures d\'interdiction proportionnées à l\'importance du risque de contamination en fonction des circonstances locales, après avis de l\'autorité compétente en matière sanitaire, notamment en les limitant à certaines parties du territoire.');

		//Add text
		$p->Body('Enfin, l\'avis de contravention mentionne les dispositions de l\'article 4-1 du décret du 29 octobre 2020, à savoir : ');

		//Add text
		$p->Quoted('Dans les cas où le lieu d\'exercice de l\'activité professionnelle est le domicile du client, les déplacements mentionnés au a du 1° du I de l\'article 4 ne sont, sauf intervention urgente, livraison ou lorsqu\'ils ont pour objet l\'assistance à des personnes vulnérables ou précaires ou la garde d\'enfants, autorisés qu\'entre 6 heures et 19 heures.');

		//Add text
		$p->Body('En répression, il est renvoyé à l\'article L.3136-1 du Code de la santé publique en son 3ème alinéa, dont le contenu est le suivant :');

		//Add text
		$p->Quoted('« La violation des autres interdictions ou obligations édictées en application des articles L. 3131-1 et L. 3131-15 à L. 3131-17 est punie de l\'amende prévue pour les contraventions de la quatrième classe. Cette contravention peut faire l\'objet de la procédure de l\'amende forfaitaire prévue à l\'article 529 du code de procédure pénale. Si cette violation est constatée à nouveau dans un délai de quinze jours, l\'amende est celle prévue pour les contraventions de la cinquième classe. ».');

		//Add text
		$p->Body('Cet alinéa 3 mentionne successivement l\'amende prévue pour les contraventions de la quatrième classe, ainsi que celle prévue pour la cinquième classe en cas de récidive dans un délai de 15 jours.');

		//Add text
		$p->Body('En aucun cas, il n\'est précisé la catégorie de contravention applicable à ma situation spécifique.

Plus encore, outre la confusion générée par la référence à deux classes de contravention, en aucun cas l\'article précité, ou l\'article 529 du Code de procédure pénale ne fixent le montant de l\'amende forfaitaire à laquelle je suis condamné.', 'BU');

		//Add text
		$p->Body('En effet, cette information ressort de l\'article R. 49 du Code de procédure pénale, qui dispose :');

		//Add text
		$p->Quoted('« Le montant de l\'amende forfaitaire prévue par l\'article 529 est fixé ainsi qu\'il suit : [...]

5° 135 euros pour les contraventions de la 4e classe

6° 200 euros pour les contraventions de la 5e classe ».');

		//Add text
		$p->Body('Or, cet article n\'est nullement mentionné à l\'avis de contravention reçu !

Par conséquent, l\'avis de contravention dressé à mon encontre est entaché d\'irrégularité.', 'B');

		//Add title
		$p->Title1('III/ EN TOUT ETAT DE CAUSE, SUR L\'ABSENCE DE CARACTERISATION DE L\'INFRACTION QUI M\'EST REPROCHEE');

		//Add text
		$p->Body('L\'avis de contravention ne porte pas mention des circonstances exactes de commission de l\'infraction.

(i) Pourtant, l\'article 537 du code de procédure pénale dispose que :');

		//Add text
		$p->Quoted('« Les contraventions sont prouvées soit par procès-verbaux ou rapports, soit par témoins à défaut de rapports et procès-verbaux, ou à leur appui.
Sauf dans les cas où la loi en dispose autrement, les procès-verbaux ou rapports établis par les officiers et agents de police judiciaire et les agents de police judiciaire adjoints, ou les fonctionnaires ou agents chargés de certaines fonctions de police judiciaire auxquels la loi a attribué le pouvoir de constater les contraventions, font foi jusqu\'à preuve contraire.
La preuve contraire ne peut être rapportée que par écrit ou par témoins. »');

		//Add text
		$p->Body('Par ailleurs, l\'article 429 du code de procédure pénale, en son alinéa 1er, prévoit que :');

		//Add text
		$p->Quoted('« Tout procès-verbal ou rapport n\'a de valeur probante que s\'il est régulier en la forme, si son auteur a agi dans l\'exercice de ses fonctions et a rapporté sur une matière de sa compétence ce qu\'il a vu, entendu ou constaté personnellement.
[...] ».');

		//Add text
		$p->Body('La matérialité doit ainsi être constatée dans le procès-verbal de constatation.

(ii) Concernant le couvre-feu, l\'article 4 du décret du 29 octobre 2020, qui pose l\'interdiction générale de déplacement entre 18h et 6h prévoit également expressément des exceptions. 

Ces exceptions sont limitativement listées par le décret. 

En outre, l\'article 4 du décret du 29 octobre 2020 dispose au titre du III desdites dispositions :');

		//Add text
		$p->Quoted('« Les personnes souhaitant bénéficier de l\'une des exceptions mentionnées aux I et II se munissent, lors de leurs déplacements hors de leur domicile, d\'un document leur permettant de justifier que le déplacement considéré entre dans le champ de l\'une de ces exceptions. ».');

		//Add text
		$p->Body('Il ressort de la combinaison de ces dispositions qu\'il est possible de se déplacer entre 19 heures et 6 heures, à condition d\'être muni d\'un document permettant de justifier que le déplacement entre dans le champ de l\'une des exceptions.', 'B');

		//Add title
		$p->Title3('(iii) En l\'espèce, l\'avis de contravention indique que l\'infraction qui m\'est reprochée, est :');

		//Add text
		$p->Quoted('« CIRCULATION A UNE HEURE INTERDITE (...) ».', 'BI');

		//Add text
		$p->Body('Dès lors, il est patent qu\'il m\'est reproché de m\'être déplacé entre 19 heures et 6 heures du matin.');

		//Add text
		$p->Body('Ainsi, c\'est sur le fondement du principe d\'interdiction générale de déplacement que j\'ai été verbalisé.', 'BU');

		//Add text
		$p->Body('Or, force est de constater que l\'avis de contravention ne fait aucunement mention de l\'existence même des exceptions et encore moins de l\'absence d\'un document justificatif.', 'B');

		//Add text
		$p->Body('Il est donc impossible de déterminer si mon déplacement entrait dans le cadre d\'une des exceptions prévues par le décret du 29 octobre 2020, et si j\'étais en possession du justificatif y afférent. 

Pour caractériser l\'infraction, l\'agent verbalisateur aurait dû préciser les raisons pour lesquelles il a jugé mon déplacement interdit malgré les dispositions relatives aux exceptions. ');

		//Add text
		$p->Body('En s\'abstenant de mentionner que mon déplacement n\'était pas justifié, l\'infraction qui m\'est reprochée ne saurait être caractérisée.', 'B');

		//Add text
		$p->Body('A tout point de vue, l\'avis de contravention reçu souffre de plusieurs manquements graves de base légale à savoir :', 'B');

		//Add text
		$p->Quoted('- L\'avis de contravention est dépourvu de base légale puisque l\'infraction prétendument commise n\'est pas visée par un texte de répression ;

- A considérer qu\'il soit besoin d\'examiner le contenu de l\'avis de contravention, il devra être considéré qu\'au regard du principe de légalité, lequel a pour corollaire le principe de légalité des peines, les textes de prévention ne sont pas correctement visés.

- Enfin, force est de constater que l\'infraction qui m\'est reprochée n\'est aucunement caractérisée.', 'BU');

		//Add text
		$p->Body('Or, en application des principes fondamentaux et constitutionnels, un fait ne peut être réprimé pénalement qu\'en vertu d\'une disposition pénale suffisamment précise et claire, et ce afin notamment d\'exclure tout arbitraire dans le prononcé des peines.');

		//Add text
		$p->Body('Par conséquent, cette condamnation pénale constitue une violation des principes essentiels rappelés.', 'BU');

		//Add text
		$p->Body('Pour l\'ensemble de ces raisons, je vous remercie, Madame ou Monsieur l\'Officier du Ministère Public, de faire droit à cette requête en me confirmant que vous renoncez à toute poursuite du chef de la contravention contestée et, le cas échéant, vous invite, à me convoquer à une prochaine audience.

Vous remerciant de l\'accueil et l\'attention que vous réserverez à la présente,

Je vous prie d\'agréer, Madame, Monsieur l\'Officier du Ministère Public, l\'expression de mes sentiments distingués.');

		//Add text
		$p->Body('Signé, '.$civility.' '.$forename.' '.$surname);

		//Close pdf
		$p->Close();

		//Return pdf
		return $p->Output('S');
	}

	//Set multi member
	public function Multi($text, $x = 0, $style = '', $size = 9, $line = 4, $align = 'J') {
		//Set font
		$this->SetFont('Times', $style, $size);

		//Set X
		$this->SetX($this->GetX() + $x);

		//Add text
		$this->MultiCell(0, 4, utf8_decode($text), 0, $align);

		//Jump line
		$this->Ln($line);
	}

	//Set Title1 member
	public function Title1($text) {
		//Jump line
		$this->Ln(4);

		//Set font
		$this->SetFont('Times', 'B', 12);

		//Add text
		$this->MultiCell(0, 4, utf8_decode($text), 0, 'L');

		//Jump line
		$this->Ln(4);
	}

	//Set Title2 member
	public function Title2($text) {
		//Set font
		$this->SetFont('Times', 'BU', 11);

		//Set X
		$this->SetX($this->GetX() + 2);

		//Add text
		$this->MultiCell(0, 4, utf8_decode($text), 0, 'L');

		//Jump line
		$this->Ln(4);
	}

	//Set Title3 member
	public function Title3($text) {
		//Set font
		$this->SetFont('Times', 'U', 10);

		//Set X
		$this->SetX($this->GetX() + 4);

		//Add text
		$this->MultiCell(0, 4, utf8_decode($text), 0, 'L');

		//Jump line
		$this->Ln(4);
	}

	//Set Body member
	public function Body($text, $style = '') {
		//Set font
		$this->SetFont('Times', $style, 9);

		//Add text
		$this->MultiCell(0, 3, utf8_decode($text), 0, 'J');

		//Jump line
		$this->Ln(2);
	}

	//Set Quoted member
	public function Quoted($text, $style = 'I') {
		//Set font
		$this->SetFont('Times', $style, 9);

		//Set X
		$this->SetX($this->GetX() + 6);

		//Add text
		$this->MultiCell(0, 3, utf8_decode($text), 0, 'J');

		//Jump line
		$this->Ln(2);
	}

	//Set footer hook
	public function Footer() {
		//Set at bottom
		$this->SetY(-15);
		//Set font
		$this->SetFont('Times', 'I', 8);
		//Set page number
		$this->Cell(0, 10, 'Page '.$this->PageNo().'/{nb}', 0, 0, 'R');
	}

	//Replace close member
	public function Close() {
		//Replace alias nb pages
		$this->AliasNbPages();

		//Call parent close
		parent::Close();
	}
}
